@@ -91,8 +91,8 @@ static integer c__100 = 100;
     grsvpt_(&c_b13, &c_b14, &c_b13, &c_b14);
     grstrn_(&c__4);
     grstrf_();
-    ussttl_("FREQUENCY", "/s", "POWER", "m^{2}/s^{2}", (ftnlen)9, (ftnlen)2, (
-	    ftnlen)5, (ftnlen)11);
+    ussttl_("FREQUENCY", "/s", "POWER", "m\\^{2}/s\\^{2}", (ftnlen)9, (ftnlen)
+	    2, (ftnlen)5, (ftnlen)13);
     usdaxs_();
     uulin_(&c__100, x, y);
     grcls_();
