@@ -1,9 +1,16 @@
-/* sglidx.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
@@ -18,9 +25,9 @@ static real c_b20 = .015f;
 static integer c__0 = 0;
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
-/* Main program */ MAIN__(void)
+/* Main program */ int MAIN__(void)
 {
     /* System generated locals */
     real r__1, r__2;
@@ -32,16 +39,16 @@ static integer c__0 = 0;
 
     /* Local variables */
     static integer i__, j;
-    extern /* Subroutine */ int sgcls_(void), sgfrm_(void), slmgn_(real *, 
-	    real *, real *, real *), sgopn_(integer *);
     static real x1, x2, y1, y2;
     static integer iw;
-    extern /* Subroutine */ int sgpwsn_(void), sglnzv_(real *, real *, real *,
-	     real *, integer *), slsttl_(char *, char *, real *, real *, real 
-	    *, integer *, ftnlen, ftnlen), sgtxzv_(real *, real *, char *, 
-	    real *, integer *, integer *, integer *, ftnlen);
     static char chr[2];
     static integer idx;
+    extern /* Subroutine */ int sgcls_(void), sgfrm_(void), slmgn_(real *, 
+	    real *, real *, real *), sgopn_(integer *), sgpwsn_(void), 
+	    sglnzv_(real *, real *, real *, real *, integer *), slsttl_(char *
+	    , char *, real *, real *, real *, integer *, ftnlen, ftnlen), 
+	    sgtxzv_(real *, real *, char *, real *, integer *, integer *, 
+	    integer *, ftnlen);
 
     /* Fortran I/O blocks */
     static cilist io___1 = { 0, 6, 0, 0, 0 };
