@@ -78,8 +78,8 @@ static integer c__200 = 200;
     e_rsle();
     gropn_(&iws);
     grfrm_();
-    ussttl_("TIME", "SEC", "HEAT FLUX", "W/m^2", (ftnlen)4, (ftnlen)3, (
-	    ftnlen)9, (ftnlen)5);
+    ussttl_("TIME", "SEC", "HEAT FLUX", "W/m\\^2", (ftnlen)4, (ftnlen)3, (
+	    ftnlen)9, (ftnlen)6);
     usgrph_(&c__200, t, a);
     grcls_();
     return 0;
