@@ -30,7 +30,7 @@ static integer c__200 = 200;
     address a__1[3];
     integer i__1[3];
     real r__1;
-    char ch__1[3], ch__2[1];
+    char ch__1[4], ch__2[1];
 
     /* Builtin functions */
     double exp(doublereal);
@@ -87,12 +87,12 @@ static integer c__200 = 200;
     uscset_("CYSIDE", "L", (ftnlen)6, (ftnlen)1);
     swlget_("SYSFONT", &lsfnt, (ftnlen)7);
 /* Writing concatenation */
-    i__1[0] = 1, a__1[0] = "^";
+    i__1[0] = 2, a__1[0] = "\\^";
     csgi_(ch__2, (ftnlen)1, &c__4);
     i__1[1] = 1, a__1[1] = ch__2;
     i__1[2] = 1, a__1[2] = "C";
-    s_cat(ch__1, a__1, i__1, &c__3, (ftnlen)3);
-    ussttl_("TEMPERATURE", ch__1, "DEPTH", "m", (ftnlen)11, (ftnlen)3, (
+    s_cat(ch__1, a__1, i__1, &c__3, (ftnlen)4);
+    ussttl_("TEMPERATURE", ch__1, "DEPTH", "m", (ftnlen)11, (ftnlen)4, (
 	    ftnlen)5, (ftnlen)1);
     usgrph_(&c__200, t, z__);
     grcls_();
