@@ -1,18 +1,25 @@
-/* chkl01.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
 static integer c__1 = 1;
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
-/* Main program */ MAIN__(void)
+/* Main program */ int MAIN__(void)
 {
     /* Format strings */
     static char fmt_100[] = "(a)";
@@ -28,12 +35,11 @@ static integer c__1 = 1;
     /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
 
     /* Local variables */
-    static char char__[8], cref[8];
+    static char ch[4], char__[8], cref[8];
     extern logical lchr_(char *, char *, ftnlen, ftnlen), lchra_(char *, 
 	    ftnlen), lchrb_(char *, ftnlen), lchrc_(char *, ftnlen), lchrd_(
 	    char *, ftnlen), lchrf_(char *, ftnlen), lchrl_(char *, ftnlen), 
 	    lchrs_(char *, ftnlen);
-    static char ch[4];
 
     /* Fortran I/O blocks */
     static cilist io___1 = { 0, 6, 0, fmt_100, 0 };
