@@ -1,9 +1,16 @@
-/* fncl01.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
@@ -11,9 +18,9 @@ static integer c__1 = 1;
 static integer c_n1 = -1;
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
-/* Main program */ MAIN__(void)
+/* Main program */ int MAIN__(void)
 {
     /* System generated locals */
     char ch__1[1], ch__2[1];
@@ -22,11 +29,11 @@ static integer c_n1 = -1;
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
 
     /* Local variables */
+    extern /* Character */ VOID cns_(char *, ftnlen, integer *);
     static char cver[12];
     static integer iunit;
     extern /* Subroutine */ int dclvnm_(char *, ftnlen);
     extern integer iufopn_(void);
-    extern /* Character */ VOID cns_(char *, ftnlen, integer *);
 
     /* Fortran I/O blocks */
     static cilist io___1 = { 0, 6, 0, "(A)", 0 };
