@@ -110,13 +110,13 @@ static integer c__218 = 218;
     }
     sglnv_(&xc, &c_b7, &xc, &c_b8);
 /* -- デフォルト ---- */
-    sgtxv_(&xc, y, "SGTXV^{SUP}RST_{SUB}", (ftnlen)20);
+    sgtxv_(&xc, y, "SGTXV\\^{SUP}RST\\_{SUB}", (ftnlen)22);
 /* -- 添字 ---- */
     sglset_("LCNTL", &c_true, (ftnlen)5);
-    sgtxv_(&xc, &y[1], "SGTXV^{SUP}RST_{SUB}", (ftnlen)20);
+    sgtxv_(&xc, &y[1], "SGTXV\\^{SUP}RST\\_{SUB}", (ftnlen)22);
     sgrset_("SMALL", &c_b14, (ftnlen)5);
     sgrset_("SHIFT", &c_b14, (ftnlen)5);
-    sgtxv_(&xc, &y[2], "SGTXV^{SUP}RST_{SUB}", (ftnlen)20);
+    sgtxv_(&xc, &y[2], "SGTXV\\^{SUP}RST\\_{SUB}", (ftnlen)22);
 /* -- フォント ---- */
     sgtxv_(&xc, &y[3], "ABCDEFG abcdefg", (ftnlen)15);
     sgiset_("IFONT", &c__2, (ftnlen)5);
