@@ -1,9 +1,16 @@
-/* u2d3.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
@@ -25,9 +32,9 @@ static integer c__37 = 37;
 static integer c__7 = 7;
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
-/* Main program */ MAIN__(void)
+/* Main program */ int MAIN__(void)
 {
     /* Initialized data */
 
@@ -42,9 +49,10 @@ static integer c__7 = 7;
 	    e_wsle(void), s_rsle(cilist *), e_rsle(void);
 
     /* Local variables */
-    static real alat, alon, slat;
     static integer i__, j;
-    static real p[1369]	/* was [37][37] */;
+    static real p[1369]	/* was [37][37] */, uy1[37], uy2[7];
+    static integer iws;
+    static real alat, alon, slat;
     extern /* Subroutine */ int grcls_(void), grfrm_(void), gropn_(integer *),
 	     udcntr_(real *, integer *, integer *, integer *), grswnd_(real *,
 	     real *, real *, real *), uyaxlb_(char *, real *, integer *, real 
@@ -53,11 +61,8 @@ static integer c__7 = 7;
 	    sgpwsn_(void), uyaxdv_(char *, real *, real *, ftnlen), uwsgxb_(
 	    real *, real *, integer *), uwsgya_(real *, integer *), grsvpt_(
 	    real *, real *, real *, real *), uzlset_(char *, logical *, 
-	    ftnlen);
-    static real uy1[37], uy2[7];
-    extern /* Subroutine */ int uxsttl_(char *, char *, real *, ftnlen, 
-	    ftnlen), uysttl_(char *, char *, real *, ftnlen, ftnlen);
-    static integer iws;
+	    ftnlen), uxsttl_(char *, char *, real *, ftnlen, ftnlen), uysttl_(
+	    char *, char *, real *, ftnlen, ftnlen);
 
     /* Fortran I/O blocks */
     static cilist io___10 = { 0, 6, 0, 0, 0 };
