@@ -63,8 +63,8 @@ static integer c__51 = 51;
     grfrm_();
     glrget_("RUNDEF", &rundef, (ftnlen)6);
     grswnd_(&c_b8, &c_b9, &rundef, &rundef);
-    ussttl_("TIME", "YEAR", "HEAT FLUX", "W/m^2\"", (ftnlen)4, (ftnlen)4, (
-	    ftnlen)9, (ftnlen)6);
+    ussttl_("TIME", "YEAR", "HEAT FLUX", "W/m\\^2\"", (ftnlen)4, (ftnlen)4, (
+	    ftnlen)9, (ftnlen)7);
     usgrph_(&c__51, &rundef, y);
     grcls_();
     return 0;
