@@ -1,9 +1,16 @@
-/* dclfont.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
@@ -21,9 +28,9 @@ static integer c__3 = 3;
 static real c_b40 = .01f;
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
-/* Main program */ MAIN__(void)
+/* Main program */ int MAIN__(void)
 {
     /* System generated locals */
     real r__1, r__2;
@@ -35,24 +42,23 @@ static real c_b40 = .01f;
 	    ;
 
     /* Local variables */
+    static integer i__;
+    static char ch[3];
+    static real ux, uy;
     extern /* Character */ VOID csgi_(char *, ftnlen, integer *);
     static char cttl[16];
-    static integer i__;
     extern /* Subroutine */ int chngi_(char *, char *, integer *, char *, 
 	    ftnlen, ftnlen, ftnlen), sgcls_(void), sgfrm_(void);
     static integer ifont;
-    extern /* Subroutine */ int gropn_(integer *);
-    static char ch[3];
-    static real ux, uy;
-    extern /* Subroutine */ int sgiget_(char *, integer *, ftnlen), clower_(
-	    char *, ftnlen), sglset_(char *, logical *, ftnlen), sgswnd_(real 
-	    *, real *, real *, real *), sgstrf_(void), glistx_(char *, 
-	    integer *, ftnlen), sgstrn_(integer *), sglnzu_(real *, real *, 
-	    real *, real *, integer *), sglstx_(char *, logical *, ftnlen), 
-	    sgsvpt_(real *, real *, real *, real *), swcstx_(char *, char *, 
-	    ftnlen, ftnlen), swistx_(char *, integer *, ftnlen), sgtxzu_(real 
-	    *, real *, char *, real *, integer *, integer *, integer *, 
-	    ftnlen);
+    extern /* Subroutine */ int gropn_(integer *), sgiget_(char *, integer *, 
+	    ftnlen), clower_(char *, ftnlen), sglset_(char *, logical *, 
+	    ftnlen), sgswnd_(real *, real *, real *, real *), sgstrf_(void), 
+	    glistx_(char *, integer *, ftnlen), sgstrn_(integer *), sglnzu_(
+	    real *, real *, real *, real *, integer *), sglstx_(char *, 
+	    logical *, ftnlen), sgsvpt_(real *, real *, real *, real *), 
+	    swcstx_(char *, char *, ftnlen, ftnlen), swistx_(char *, integer *
+	    , ftnlen), sgtxzu_(real *, real *, char *, real *, integer *, 
+	    integer *, integer *, ftnlen);
 
     /* Fortran I/O blocks */
     static icilist io___7 = { 0, ch, 0, "(I3)", 3, 1 };
