@@ -26,7 +26,7 @@ static integer c__3 = 3;
 {
     /* Initialized data */
 
-    static char cparas[8*121] = "RDX     " "RDY     " "LCLIP   " "LCHAR   " 
+    static char cparas[8*122] = "RDX     " "RDY     " "LCLIP   " "LCHAR   " 
 	    "LLNINT  " "LGCINT  " "LSOFTF  " "LCL2TN  " "IRMODE  " "BITLEN  " 
 	    "MOVE    " "NBITS   " "LCNTL   " "SMALL   " "SHIFT   " "ISUP    " 
 	    "ISUB    " "IRST    " "LFULL   " "PMFACT  " "NPMSKIP " "RFAROT  " 
@@ -46,13 +46,13 @@ static integer c__3 = 3;
 	    "LFGBG   " "L2TO3   " "VXMIN3  " "VXMAX3  " "VYMIN3  " "VYMAX3  " 
 	    "VZMIN3  " "VZMAX3  " "UXMIN3  " "UXMAX3  " "UYMIN3  " "UYMAX3  " 
 	    "UZMIN3  " "UZMAX3  " "VXORG3  " "VYORG3  " "VZORG3  " "SIMFAC3 " 
-	    "LXLOG3  " "LYLOG3  " "LZLOG3  ";
-    static integer itype[121] = { 3,3,2,2,2,2,2,2,1,3,1,1,2,3,3,1,1,1,2,3,1,3,
+	    "LXLOG3  " "LYLOG3  " "LZLOG3  " "MARKFONT";
+    static integer itype[122] = { 3,3,2,2,2,2,2,2,1,3,1,1,2,3,3,1,1,1,2,3,1,3,
 	    3,1,1,2,2,1,3,3,3,1,2,1,3,2,3,2,2,3,3,3,3,2,2,1,0,1,1,3,3,3,3,3,3,
 	    3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,2,1,1,1,3,1,2,2,3,3,3,2,1,3,
-	    3,3,3,3,3,3,3,3,3,1,1,3,2,2,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,2,2,2 
-	    };
-    static char cparal[40*121] = "INTERPOLATION_ANGLE_X                   " 
+	    3,3,3,3,3,3,3,3,3,1,1,3,2,2,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,2,2,2,
+	    2 };
+    static char cparal[40*122] = "INTERPOLATION_ANGLE_X                   " 
 	    "INTERPOLATION_ANGLE_Y                   " "ENABLE_CLIPPING     "
 	    "                    " "ENABLE_LINE_LABELING                    " 
 	    "ENABLE_LINEAR_INTERPOLATION             " "ENABLE_GREATCIRCLE_I"
@@ -132,7 +132,8 @@ static integer c__3 = 3;
 	    "++++VYORG3                              " "++++VZORG3          "
 	    "                    " "++++SIMFAC3                             " 
 	    "++++LXLOG3                              " "++++LYLOG3          "
-	    "                    " "++++LZLOG3                              ";
+	    "                    " "++++LZLOG3                              " 
+	    "USE_DCLMARKER_FONT                      ";
 
     /* System generated locals */
     address a__1[3];
@@ -166,12 +167,12 @@ static integer c__3 = 3;
 	}
 
 /*     / LONG  NAME / */
-    *ncp = 121;
+    *ncp = 122;
     return 0;
 /* ----------------------------------------------------------------------- */
 
 L_sgpqid:
-    for (n = 1; n <= 121; ++n) {
+    for (n = 1; n <= 122; ++n) {
 	if (lchreq_(cp, cparas + (n - 1 << 3), cp_len, (ftnlen)8) || lchreq_(
 		cp, cparal + (n - 1) * 40, cp_len, (ftnlen)40)) {
 	    *idx = n;
@@ -189,7 +190,7 @@ L_sgpqid:
 /* ----------------------------------------------------------------------- */
 
 L_sgpqcp:
-    if (1 <= *idx && *idx <= 121) {
+    if (1 <= *idx && *idx <= 122) {
 	s_copy(cp, cparas + (*idx - 1 << 3), cp_len, (ftnlen)8);
     } else {
 	msgdmp_("E", "SGPQCP", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
@@ -199,7 +200,7 @@ L_sgpqcp:
 /* ----------------------------------------------------------------------- */
 
 L_sgpqcl:
-    if (1 <= *idx && *idx <= 121) {
+    if (1 <= *idx && *idx <= 122) {
 	s_copy(cp, cparal + (*idx - 1) * 40, cp_len, (ftnlen)40);
     } else {
 	msgdmp_("E", "SGPQCL", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
@@ -209,7 +210,7 @@ L_sgpqcl:
 /* ----------------------------------------------------------------------- */
 
 L_sgpqit:
-    if (1 <= *idx && *idx <= 121) {
+    if (1 <= *idx && *idx <= 122) {
 	*itp = itype[*idx - 1];
     } else {
 	msgdmp_("E", "SGPQIT", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
@@ -219,7 +220,7 @@ L_sgpqit:
 /* ----------------------------------------------------------------------- */
 
 L_sgpqvl:
-    if (1 <= *idx && *idx <= 121) {
+    if (1 <= *idx && *idx <= 122) {
 	if (itype[*idx - 1] == 1) {
 	    sgiqid_(cparas + (*idx - 1 << 3), &id, (ftnlen)8);
 	    sgiqvl_(&id, ipara);
@@ -238,7 +239,7 @@ L_sgpqvl:
 /* ----------------------------------------------------------------------- */
 
 L_sgpsvl:
-    if (1 <= *idx && *idx <= 121) {
+    if (1 <= *idx && *idx <= 122) {
 	if (itype[*idx - 1] == 1) {
 	    sgiqid_(cparas + (*idx - 1 << 3), &id, (ftnlen)8);
 	    sgisvl_(&id, ipara);
@@ -257,7 +258,7 @@ L_sgpsvl:
 /* ----------------------------------------------------------------------- */
 
 L_sgpqin:
-    for (n = 1; n <= 121; ++n) {
+    for (n = 1; n <= 122; ++n) {
 	if (lchreq_(cp, cparas + (n - 1 << 3), cp_len, (ftnlen)8) || lchreq_(
 		cp, cparal + (n - 1) * 40, cp_len, (ftnlen)40)) {
 	    *in = n;
