@@ -31,9 +31,10 @@ static integer c__0 = 0;
 	integer *mb, logical *lwdatr, logical *lclatr, logical *ltnatr, 
 	logical *limatr, logical *lptatr, real *wsxmn, real *wsxmx, real *
 	wsymn, real *wsymx, real *fact, integer *iwtrot, real *chars, integer 
-	*nchz, real *wxch, real *wych, real *fontname, integer *fntnum, 
+	*nchz, real *wxch, real *wych, char *fontname, integer *fntnum, 
 	integer *inum, integer *ifmax, real *qsizexrate, integer *ncz, 
-	integer *irota, integer *icentz, ftnlen cobj_len, ftnlen comm_len)
+	integer *irota, integer *icentz, ftnlen cobj_len, ftnlen comm_len, 
+	ftnlen fontname_len)
 {
     /* Initialized data */
 
@@ -51,8 +52,8 @@ static integer c__0 = 0;
     /* Subroutine */ int s_cat(char *, char **, integer *, integer *, ftnlen);
 
     /* Local variables */
-    extern /* Subroutine */ int zgfontname_(integer *, real *, integer *), 
-	    zgnumfonts_(integer *);
+    extern /* Subroutine */ int zgfontname_(integer *, char *, integer *, 
+	    ftnlen), zgnumfonts_(integer *);
     static integer ifl, iws, jws;
     static char cmap[80];
     extern integer lenc_(char *, ftnlen);
@@ -65,7 +66,7 @@ static integer c__0 = 0;
     extern integer lenz_(char *, ftnlen);
     static char cout[80];
     static integer isup, irst;
-    extern /* Subroutine */ int zgselectfont_(real *);
+    extern /* Subroutine */ int zgselectfont_(char *, ftnlen);
     static logical lfgbg;
     extern /* Subroutine */ int chngi_(char *, char *, integer *, char *, 
 	    ftnlen, ftnlen, ftnlen);
@@ -124,7 +125,7 @@ static integer c__0 = 0;
 	    zgqptc_(logical *), zgqrct_(real *, real *, real *, real *, real *
 	    ), zgsrot_(integer *), zgqtxw_(real *, integer *, real *, real *);
     static char cimgfmt[8];
-    extern /* Subroutine */ int zgftfc_(real *);
+    extern /* Subroutine */ int zgftfc_(char *, ftnlen);
     static integer idmpdgt;
     static real rimgcmp;
     extern /* Subroutine */ int zgflash_(void), zgclini_(char *, logical *, 
@@ -613,7 +614,7 @@ L_swqtxw:
 /* ----------------------------------------------------------------------- */
 
 L_swftfc:
-    zgftfc_(fontname);
+    zgftfc_(fontname, fontname_len);
     return 0;
 /* ----------------------------------------------------------------------- */
 
@@ -627,13 +628,13 @@ L_swslft:
 	msgdmp_("M", "SWSLFT", "DIALOG NEEDS WINDOW.DEFAULT FONT IS USED", (
 		ftnlen)1, (ftnlen)6, (ftnlen)40);
     } else {
-	zgselectfont_(fontname);
+	zgselectfont_(fontname, fontname_len);
     }
     return 0;
 /* ----------------------------------------------------------------------- */
 
 L_swgtft:
-    zgfontname_(inum, fontname, ifmax);
+    zgfontname_(inum, fontname, ifmax, fontname_len);
     return 0;
 /* ----------------------------------------------------------------------- */
 
@@ -686,9 +687,9 @@ L_swtxt:
 	    (real *)0, (integer *)0, (integer *)0, (integer *)0, (logical *)0,
 	     (logical *)0, (logical *)0, (logical *)0, (logical *)0, (real *)
 	    0, (real *)0, (real *)0, (real *)0, (real *)0, (integer *)0, (
-	    real *)0, (integer *)0, (real *)0, (real *)0, (real *)0, (integer 
+	    real *)0, (integer *)0, (real *)0, (real *)0, (char *)0, (integer 
 	    *)0, (integer *)0, (integer *)0, (real *)0, (integer *)0, (
-	    integer *)0, (integer *)0, (ftnint)0, (ftnint)0);
+	    integer *)0, (integer *)0, (ftnint)0, (ftnint)0, (ftnint)0);
     }
 
 /* Subroutine */ int swdcls_(void)
@@ -701,9 +702,9 @@ L_swtxt:
 	    (real *)0, (integer *)0, (integer *)0, (integer *)0, (logical *)0,
 	     (logical *)0, (logical *)0, (logical *)0, (logical *)0, (real *)
 	    0, (real *)0, (real *)0, (real *)0, (real *)0, (integer *)0, (
-	    real *)0, (integer *)0, (real *)0, (real *)0, (real *)0, (integer 
+	    real *)0, (integer *)0, (real *)0, (real *)0, (char *)0, (integer 
 	    *)0, (integer *)0, (integer *)0, (real *)0, (integer *)0, (
-	    integer *)0, (integer *)0, (ftnint)0, (ftnint)0);
+	    integer *)0, (integer *)0, (ftnint)0, (ftnint)0, (ftnint)0);
     }
 
 /* Subroutine */ int swpopn_(void)
@@ -716,9 +717,9 @@ L_swtxt:
 	    (real *)0, (integer *)0, (integer *)0, (integer *)0, (logical *)0,
 	     (logical *)0, (logical *)0, (logical *)0, (logical *)0, (real *)
 	    0, (real *)0, (real *)0, (real *)0, (real *)0, (integer *)0, (
-	    real *)0, (integer *)0, (real *)0, (real *)0, (real *)0, (integer 
+	    real *)0, (integer *)0, (real *)0, (real *)0, (char *)0, (integer 
 	    *)0, (integer *)0, (integer *)0, (real *)0, (integer *)0, (
-	    integer *)0, (integer *)0, (ftnint)0, (ftnint)0);
+	    integer *)0, (integer *)0, (ftnint)0, (ftnint)0, (ftnint)0);
     }
 
 /* Subroutine */ int swflsh_(void)
@@ -731,9 +732,9 @@ L_swtxt:
 	    (real *)0, (integer *)0, (integer *)0, (integer *)0, (logical *)0,
 	     (logical *)0, (logical *)0, (logical *)0, (logical *)0, (real *)
 	    0, (real *)0, (real *)0, (real *)0, (real *)0, (integer *)0, (
-	    real *)0, (integer *)0, (real *)0, (real *)0, (real *)0, (integer 
+	    real *)0, (integer *)0, (real *)0, (real *)0, (char *)0, (integer 
 	    *)0, (integer *)0, (integer *)0, (real *)0, (integer *)0, (
-	    integer *)0, (integer *)0, (ftnint)0, (ftnint)0);
+	    integer *)0, (integer *)0, (ftnint)0, (ftnint)0, (ftnint)0);
     }
 
 /* Subroutine */ int swpcls_(void)
@@ -746,9 +747,9 @@ L_swtxt:
 	    (real *)0, (integer *)0, (integer *)0, (integer *)0, (logical *)0,
 	     (logical *)0, (logical *)0, (logical *)0, (logical *)0, (real *)
 	    0, (real *)0, (real *)0, (real *)0, (real *)0, (integer *)0, (
-	    real *)0, (integer *)0, (real *)0, (real *)0, (real *)0, (integer 
+	    real *)0, (integer *)0, (real *)0, (real *)0, (char *)0, (integer 
 	    *)0, (integer *)0, (integer *)0, (real *)0, (integer *)0, (
-	    integer *)0, (integer *)0, (ftnint)0, (ftnint)0);
+	    integer *)0, (integer *)0, (ftnint)0, (ftnint)0, (ftnint)0);
     }
 
 /* Subroutine */ int swoopn_(char *cobj, char *comm, ftnlen cobj_len, ftnlen 
@@ -762,9 +763,9 @@ L_swtxt:
 	    integer *)0, (integer *)0, (integer *)0, (logical *)0, (logical *)
 	    0, (logical *)0, (logical *)0, (logical *)0, (real *)0, (real *)0,
 	     (real *)0, (real *)0, (real *)0, (integer *)0, (real *)0, (
-	    integer *)0, (real *)0, (real *)0, (real *)0, (integer *)0, (
+	    integer *)0, (real *)0, (real *)0, (char *)0, (integer *)0, (
 	    integer *)0, (integer *)0, (real *)0, (integer *)0, (integer *)0, 
-	    (integer *)0, cobj_len, comm_len);
+	    (integer *)0, cobj_len, comm_len, (ftnint)0);
     }
 
 /* Subroutine */ int swocls_(char *cobj, ftnlen cobj_len)
@@ -777,9 +778,9 @@ L_swtxt:
 	    integer *)0, (integer *)0, (integer *)0, (logical *)0, (logical *)
 	    0, (logical *)0, (logical *)0, (logical *)0, (real *)0, (real *)0,
 	     (real *)0, (real *)0, (real *)0, (integer *)0, (real *)0, (
-	    integer *)0, (real *)0, (real *)0, (real *)0, (integer *)0, (
+	    integer *)0, (real *)0, (real *)0, (char *)0, (integer *)0, (
 	    integer *)0, (integer *)0, (real *)0, (integer *)0, (integer *)0, 
-	    (integer *)0, cobj_len, (ftnint)0);
+	    (integer *)0, cobj_len, (ftnint)0, (ftnint)0);
     }
 
 /* Subroutine */ int swqfcc_(logical *lfcatr)
@@ -792,9 +793,9 @@ L_swtxt:
 	    integer *)0, (integer *)0, (integer *)0, (logical *)0, (logical *)
 	    0, (logical *)0, (logical *)0, (logical *)0, (real *)0, (real *)0,
 	     (real *)0, (real *)0, (real *)0, (integer *)0, (real *)0, (
-	    integer *)0, (real *)0, (real *)0, (real *)0, (integer *)0, (
+	    integer *)0, (real *)0, (real *)0, (char *)0, (integer *)0, (
 	    integer *)0, (integer *)0, (real *)0, (integer *)0, (integer *)0, 
-	    (integer *)0, (ftnint)0, (ftnint)0);
+	    (integer *)0, (ftnint)0, (ftnint)0, (ftnint)0);
     }
 
 /* Subroutine */ int swsfcm_(integer *lfcmod)
@@ -807,9 +808,9 @@ L_swtxt:
 	    integer *)0, (integer *)0, (integer *)0, (logical *)0, (logical *)
 	    0, (logical *)0, (logical *)0, (logical *)0, (real *)0, (real *)0,
 	     (real *)0, (real *)0, (real *)0, (integer *)0, (real *)0, (
-	    integer *)0, (real *)0, (real *)0, (real *)0, (integer *)0, (
+	    integer *)0, (real *)0, (real *)0, (char *)0, (integer *)0, (
 	    integer *)0, (integer *)0, (real *)0, (integer *)0, (integer *)0, 
-	    (integer *)0, (ftnint)0, (ftnint)0);
+	    (integer *)0, (ftnint)0, (ftnint)0, (ftnint)0);
     }
 
 /* Subroutine */ int swswdi_(integer *iwdidx)
@@ -822,9 +823,9 @@ L_swtxt:
 	    (real *)0, (integer *)0, (integer *)0, (integer *)0, (logical *)0,
 	     (logical *)0, (logical *)0, (logical *)0, (logical *)0, (real *)
 	    0, (real *)0, (real *)0, (real *)0, (real *)0, (integer *)0, (
-	    real *)0, (integer *)0, (real *)0, (real *)0, (real *)0, (integer 
+	    real *)0, (integer *)0, (real *)0, (real *)0, (char *)0, (integer 
 	    *)0, (integer *)0, (integer *)0, (real *)0, (integer *)0, (
-	    integer *)0, (integer *)0, (ftnint)0, (ftnint)0);
+	    integer *)0, (integer *)0, (ftnint)0, (ftnint)0, (ftnint)0);
     }
 
 /* Subroutine */ int swscli_(integer *iclidx, logical *lfcatr)
@@ -837,9 +838,9 @@ L_swtxt:
 	    integer *)0, (integer *)0, (integer *)0, (logical *)0, (logical *)
 	    0, (logical *)0, (logical *)0, (logical *)0, (real *)0, (real *)0,
 	     (real *)0, (real *)0, (real *)0, (integer *)0, (real *)0, (
-	    integer *)0, (real *)0, (real *)0, (real *)0, (integer *)0, (
+	    integer *)0, (real *)0, (real *)0, (char *)0, (integer *)0, (
 	    integer *)0, (integer *)0, (real *)0, (integer *)0, (integer *)0, 
-	    (integer *)0, (ftnint)0, (ftnint)0);
+	    (integer *)0, (ftnint)0, (ftnint)0, (ftnint)0);
     }
 
 /* Subroutine */ int swslcl_(integer *icolor)
@@ -852,9 +853,9 @@ L_swtxt:
 	     (integer *)0, (integer *)0, (integer *)0, (logical *)0, (logical 
 	    *)0, (logical *)0, (logical *)0, (logical *)0, (real *)0, (real *)
 	    0, (real *)0, (real *)0, (real *)0, (integer *)0, (real *)0, (
-	    integer *)0, (real *)0, (real *)0, (real *)0, (integer *)0, (
+	    integer *)0, (real *)0, (real *)0, (char *)0, (integer *)0, (
 	    integer *)0, (integer *)0, (real *)0, (integer *)0, (integer *)0, 
-	    (integer *)0, (ftnint)0, (ftnint)0);
+	    (integer *)0, (ftnint)0, (ftnint)0, (ftnint)0);
     }
 
 /* Subroutine */ int swsfw_(integer *iwidx)
@@ -867,9 +868,9 @@ L_swtxt:
 	     (integer *)0, (integer *)0, (integer *)0, (logical *)0, (logical 
 	    *)0, (logical *)0, (logical *)0, (logical *)0, (real *)0, (real *)
 	    0, (real *)0, (real *)0, (real *)0, (integer *)0, (real *)0, (
-	    integer *)0, (real *)0, (real *)0, (real *)0, (integer *)0, (
+	    integer *)0, (real *)0, (real *)0, (char *)0, (integer *)0, (
 	    integer *)0, (integer *)0, (real *)0, (integer *)0, (integer *)0, 
-	    (integer *)0, (ftnint)0, (ftnint)0);
+	    (integer *)0, (ftnint)0, (ftnint)0, (ftnint)0);
     }
 
 /* Subroutine */ int swgopn_(void)
@@ -882,9 +883,9 @@ L_swtxt:
 	    (real *)0, (integer *)0, (integer *)0, (integer *)0, (logical *)0,
 	     (logical *)0, (logical *)0, (logical *)0, (logical *)0, (real *)
 	    0, (real *)0, (real *)0, (real *)0, (real *)0, (integer *)0, (
-	    real *)0, (integer *)0, (real *)0, (real *)0, (real *)0, (integer 
+	    real *)0, (integer *)0, (real *)0, (real *)0, (char *)0, (integer 
 	    *)0, (integer *)0, (integer *)0, (real *)0, (integer *)0, (
-	    integer *)0, (integer *)0, (ftnint)0, (ftnint)0);
+	    integer *)0, (integer *)0, (ftnint)0, (ftnint)0, (ftnint)0);
     }
 
 /* Subroutine */ int swgmov_(real *wx, real *wy)
@@ -897,9 +898,9 @@ L_swtxt:
 	    integer *)0, (integer *)0, (integer *)0, (logical *)0, (logical *)
 	    0, (logical *)0, (logical *)0, (logical *)0, (real *)0, (real *)0,
 	     (real *)0, (real *)0, (real *)0, (integer *)0, (real *)0, (
-	    integer *)0, (real *)0, (real *)0, (real *)0, (integer *)0, (
+	    integer *)0, (real *)0, (real *)0, (char *)0, (integer *)0, (
 	    integer *)0, (integer *)0, (real *)0, (integer *)0, (integer *)0, 
-	    (integer *)0, (ftnint)0, (ftnint)0);
+	    (integer *)0, (ftnint)0, (ftnint)0, (ftnint)0);
     }
 
 /* Subroutine */ int swgplt_(real *wx, real *wy)
@@ -912,9 +913,9 @@ L_swtxt:
 	    integer *)0, (integer *)0, (integer *)0, (logical *)0, (logical *)
 	    0, (logical *)0, (logical *)0, (logical *)0, (real *)0, (real *)0,
 	     (real *)0, (real *)0, (real *)0, (integer *)0, (real *)0, (
-	    integer *)0, (real *)0, (real *)0, (real *)0, (integer *)0, (
+	    integer *)0, (real *)0, (real *)0, (char *)0, (integer *)0, (
 	    integer *)0, (integer *)0, (real *)0, (integer *)0, (integer *)0, 
-	    (integer *)0, (ftnint)0, (ftnint)0);
+	    (integer *)0, (ftnint)0, (ftnint)0, (ftnint)0);
     }
 
 /* Subroutine */ int swgcls_(void)
@@ -927,9 +928,9 @@ L_swtxt:
 	    (real *)0, (integer *)0, (integer *)0, (integer *)0, (logical *)0,
 	     (logical *)0, (logical *)0, (logical *)0, (logical *)0, (real *)
 	    0, (real *)0, (real *)0, (real *)0, (real *)0, (integer *)0, (
-	    real *)0, (integer *)0, (real *)0, (real *)0, (real *)0, (integer 
+	    real *)0, (integer *)0, (real *)0, (real *)0, (char *)0, (integer 
 	    *)0, (integer *)0, (integer *)0, (real *)0, (integer *)0, (
-	    integer *)0, (integer *)0, (ftnint)0, (ftnint)0);
+	    integer *)0, (integer *)0, (ftnint)0, (ftnint)0, (ftnint)0);
     }
 
 /* Subroutine */ int swstcl_(integer *icolor)
@@ -942,9 +943,9 @@ L_swtxt:
 	     (integer *)0, (integer *)0, (integer *)0, (logical *)0, (logical 
 	    *)0, (logical *)0, (logical *)0, (logical *)0, (real *)0, (real *)
 	    0, (real *)0, (real *)0, (real *)0, (integer *)0, (real *)0, (
-	    integer *)0, (real *)0, (real *)0, (real *)0, (integer *)0, (
+	    integer *)0, (real *)0, (real *)0, (char *)0, (integer *)0, (
 	    integer *)0, (integer *)0, (real *)0, (integer *)0, (integer *)0, 
-	    (integer *)0, (ftnint)0, (ftnint)0);
+	    (integer *)0, (ftnint)0, (ftnint)0, (ftnint)0);
     }
 
 /* Subroutine */ int swgton_(integer *np, real *wpx, real *wpy, integer *
@@ -958,9 +959,9 @@ L_swtxt:
 	    integer *)0, (integer *)0, (logical *)0, (logical *)0, (logical *)
 	    0, (logical *)0, (logical *)0, (real *)0, (real *)0, (real *)0, (
 	    real *)0, (real *)0, (integer *)0, (real *)0, (integer *)0, (real 
-	    *)0, (real *)0, (real *)0, (integer *)0, (integer *)0, (integer *)
+	    *)0, (real *)0, (char *)0, (integer *)0, (integer *)0, (integer *)
 	    0, (real *)0, (integer *)0, (integer *)0, (integer *)0, (ftnint)0,
-	     (ftnint)0);
+	     (ftnint)0, (ftnint)0);
     }
 
 /* Subroutine */ int swiopn_(integer *iwx, integer *iwy, integer *imw, 
@@ -974,9 +975,9 @@ L_swtxt:
 	    0, (integer *)0, (integer *)0, (logical *)0, (logical *)0, (
 	    logical *)0, (logical *)0, (logical *)0, (real *)0, (real *)0, (
 	    real *)0, (real *)0, (real *)0, (integer *)0, (real *)0, (integer 
-	    *)0, (real *)0, (real *)0, (real *)0, (integer *)0, (integer *)0, 
+	    *)0, (real *)0, (real *)0, (char *)0, (integer *)0, (integer *)0, 
 	    (integer *)0, (real *)0, (integer *)0, (integer *)0, (integer *)0,
-	     (ftnint)0, (ftnint)0);
+	     (ftnint)0, (ftnint)0, (ftnint)0);
     }
 
 /* Subroutine */ int swidat_(integer *image, integer *nlen)
@@ -989,9 +990,9 @@ L_swtxt:
 	    (real *)0, image, nlen, (integer *)0, (logical *)0, (logical *)0, 
 	    (logical *)0, (logical *)0, (logical *)0, (real *)0, (real *)0, (
 	    real *)0, (real *)0, (real *)0, (integer *)0, (real *)0, (integer 
-	    *)0, (real *)0, (real *)0, (real *)0, (integer *)0, (integer *)0, 
+	    *)0, (real *)0, (real *)0, (char *)0, (integer *)0, (integer *)0, 
 	    (integer *)0, (real *)0, (integer *)0, (integer *)0, (integer *)0,
-	     (ftnint)0, (ftnint)0);
+	     (ftnint)0, (ftnint)0, (ftnint)0);
     }
 
 /* Subroutine */ int swiclr_(integer *image, integer *nlen)
@@ -1004,9 +1005,9 @@ L_swtxt:
 	    (real *)0, image, nlen, (integer *)0, (logical *)0, (logical *)0, 
 	    (logical *)0, (logical *)0, (logical *)0, (real *)0, (real *)0, (
 	    real *)0, (real *)0, (real *)0, (integer *)0, (real *)0, (integer 
-	    *)0, (real *)0, (real *)0, (real *)0, (integer *)0, (integer *)0, 
+	    *)0, (real *)0, (real *)0, (char *)0, (integer *)0, (integer *)0, 
 	    (integer *)0, (real *)0, (integer *)0, (integer *)0, (integer *)0,
-	     (ftnint)0, (ftnint)0);
+	     (ftnint)0, (ftnint)0, (ftnint)0);
     }
 
 /* Subroutine */ int swicls_(void)
@@ -1019,9 +1020,9 @@ L_swtxt:
 	    (real *)0, (integer *)0, (integer *)0, (integer *)0, (logical *)0,
 	     (logical *)0, (logical *)0, (logical *)0, (logical *)0, (real *)
 	    0, (real *)0, (real *)0, (real *)0, (real *)0, (integer *)0, (
-	    real *)0, (integer *)0, (real *)0, (real *)0, (real *)0, (integer 
+	    real *)0, (integer *)0, (real *)0, (real *)0, (char *)0, (integer 
 	    *)0, (integer *)0, (integer *)0, (real *)0, (integer *)0, (
-	    integer *)0, (integer *)0, (ftnint)0, (ftnint)0);
+	    integer *)0, (integer *)0, (ftnint)0, (ftnint)0, (ftnint)0);
     }
 
 /* Subroutine */ int swqpnt_(real *wx, real *wy, integer *mb)
@@ -1034,9 +1035,9 @@ L_swtxt:
 	    integer *)0, (integer *)0, mb, (logical *)0, (logical *)0, (
 	    logical *)0, (logical *)0, (logical *)0, (real *)0, (real *)0, (
 	    real *)0, (real *)0, (real *)0, (integer *)0, (real *)0, (integer 
-	    *)0, (real *)0, (real *)0, (real *)0, (integer *)0, (integer *)0, 
+	    *)0, (real *)0, (real *)0, (char *)0, (integer *)0, (integer *)0, 
 	    (integer *)0, (real *)0, (integer *)0, (integer *)0, (integer *)0,
-	     (ftnint)0, (ftnint)0);
+	     (ftnint)0, (ftnint)0, (ftnint)0);
     }
 
 /* Subroutine */ int swfint_(real *wx, real *wy, integer *iwx, integer *iwy)
@@ -1049,9 +1050,9 @@ L_swtxt:
 	    integer *)0, (integer *)0, (logical *)0, (logical *)0, (logical *)
 	    0, (logical *)0, (logical *)0, (real *)0, (real *)0, (real *)0, (
 	    real *)0, (real *)0, (integer *)0, (real *)0, (integer *)0, (real 
-	    *)0, (real *)0, (real *)0, (integer *)0, (integer *)0, (integer *)
+	    *)0, (real *)0, (char *)0, (integer *)0, (integer *)0, (integer *)
 	    0, (real *)0, (integer *)0, (integer *)0, (integer *)0, (ftnint)0,
-	     (ftnint)0);
+	     (ftnint)0, (ftnint)0);
     }
 
 /* Subroutine */ int swiint_(integer *iwx, integer *iwy, real *wx, real *wy)
@@ -1064,9 +1065,9 @@ L_swtxt:
 	    integer *)0, (integer *)0, (logical *)0, (logical *)0, (logical *)
 	    0, (logical *)0, (logical *)0, (real *)0, (real *)0, (real *)0, (
 	    real *)0, (real *)0, (integer *)0, (real *)0, (integer *)0, (real 
-	    *)0, (real *)0, (real *)0, (integer *)0, (integer *)0, (integer *)
+	    *)0, (real *)0, (char *)0, (integer *)0, (integer *)0, (integer *)
 	    0, (real *)0, (integer *)0, (integer *)0, (integer *)0, (ftnint)0,
-	     (ftnint)0);
+	     (ftnint)0, (ftnint)0);
     }
 
 /* Subroutine */ int swqwdc_(logical *lwdatr)
@@ -1079,9 +1080,9 @@ L_swtxt:
 	    (real *)0, (integer *)0, (integer *)0, (integer *)0, lwdatr, (
 	    logical *)0, (logical *)0, (logical *)0, (logical *)0, (real *)0, 
 	    (real *)0, (real *)0, (real *)0, (real *)0, (integer *)0, (real *)
-	    0, (integer *)0, (real *)0, (real *)0, (real *)0, (integer *)0, (
+	    0, (integer *)0, (real *)0, (real *)0, (char *)0, (integer *)0, (
 	    integer *)0, (integer *)0, (real *)0, (integer *)0, (integer *)0, 
-	    (integer *)0, (ftnint)0, (ftnint)0);
+	    (integer *)0, (ftnint)0, (ftnint)0, (ftnint)0);
     }
 
 /* Subroutine */ int swqclc_(logical *lclatr)
@@ -1094,9 +1095,9 @@ L_swtxt:
 	    (real *)0, (integer *)0, (integer *)0, (integer *)0, (logical *)0,
 	     lclatr, (logical *)0, (logical *)0, (logical *)0, (real *)0, (
 	    real *)0, (real *)0, (real *)0, (real *)0, (integer *)0, (real *)
-	    0, (integer *)0, (real *)0, (real *)0, (real *)0, (integer *)0, (
+	    0, (integer *)0, (real *)0, (real *)0, (char *)0, (integer *)0, (
 	    integer *)0, (integer *)0, (real *)0, (integer *)0, (integer *)0, 
-	    (integer *)0, (ftnint)0, (ftnint)0);
+	    (integer *)0, (ftnint)0, (ftnint)0, (ftnint)0);
     }
 
 /* Subroutine */ int swqtnc_(logical *ltnatr)
@@ -1109,9 +1110,9 @@ L_swtxt:
 	    (real *)0, (integer *)0, (integer *)0, (integer *)0, (logical *)0,
 	     (logical *)0, ltnatr, (logical *)0, (logical *)0, (real *)0, (
 	    real *)0, (real *)0, (real *)0, (real *)0, (integer *)0, (real *)
-	    0, (integer *)0, (real *)0, (real *)0, (real *)0, (integer *)0, (
+	    0, (integer *)0, (real *)0, (real *)0, (char *)0, (integer *)0, (
 	    integer *)0, (integer *)0, (real *)0, (integer *)0, (integer *)0, 
-	    (integer *)0, (ftnint)0, (ftnint)0);
+	    (integer *)0, (ftnint)0, (ftnint)0, (ftnint)0);
     }
 
 /* Subroutine */ int swqimc_(logical *limatr)
@@ -1124,9 +1125,9 @@ L_swtxt:
 	    (real *)0, (integer *)0, (integer *)0, (integer *)0, (logical *)0,
 	     (logical *)0, (logical *)0, limatr, (logical *)0, (real *)0, (
 	    real *)0, (real *)0, (real *)0, (real *)0, (integer *)0, (real *)
-	    0, (integer *)0, (real *)0, (real *)0, (real *)0, (integer *)0, (
+	    0, (integer *)0, (real *)0, (real *)0, (char *)0, (integer *)0, (
 	    integer *)0, (integer *)0, (real *)0, (integer *)0, (integer *)0, 
-	    (integer *)0, (ftnint)0, (ftnint)0);
+	    (integer *)0, (ftnint)0, (ftnint)0, (ftnint)0);
     }
 
 /* Subroutine */ int swqptc_(logical *lptatr)
@@ -1139,9 +1140,9 @@ L_swtxt:
 	    (real *)0, (integer *)0, (integer *)0, (integer *)0, (logical *)0,
 	     (logical *)0, (logical *)0, (logical *)0, lptatr, (real *)0, (
 	    real *)0, (real *)0, (real *)0, (real *)0, (integer *)0, (real *)
-	    0, (integer *)0, (real *)0, (real *)0, (real *)0, (integer *)0, (
+	    0, (integer *)0, (real *)0, (real *)0, (char *)0, (integer *)0, (
 	    integer *)0, (integer *)0, (real *)0, (integer *)0, (integer *)0, 
-	    (integer *)0, (ftnint)0, (ftnint)0);
+	    (integer *)0, (ftnint)0, (ftnint)0, (ftnint)0);
     }
 
 /* Subroutine */ int swqrct_(real *wsxmn, real *wsxmx, real *wsymn, real *
@@ -1155,9 +1156,9 @@ L_swtxt:
 	    (real *)0, (integer *)0, (integer *)0, (integer *)0, (logical *)0,
 	     (logical *)0, (logical *)0, (logical *)0, (logical *)0, wsxmn, 
 	    wsxmx, wsymn, wsymx, fact, (integer *)0, (real *)0, (integer *)0, 
-	    (real *)0, (real *)0, (real *)0, (integer *)0, (integer *)0, (
+	    (real *)0, (real *)0, (char *)0, (integer *)0, (integer *)0, (
 	    integer *)0, (real *)0, (integer *)0, (integer *)0, (integer *)0, 
-	    (ftnint)0, (ftnint)0);
+	    (ftnint)0, (ftnint)0, (ftnint)0);
     }
 
 /* Subroutine */ int swsrot_(integer *iwtrot)
@@ -1170,9 +1171,9 @@ L_swtxt:
 	    (real *)0, (integer *)0, (integer *)0, (integer *)0, (logical *)0,
 	     (logical *)0, (logical *)0, (logical *)0, (logical *)0, (real *)
 	    0, (real *)0, (real *)0, (real *)0, (real *)0, iwtrot, (real *)0, 
-	    (integer *)0, (real *)0, (real *)0, (real *)0, (integer *)0, (
+	    (integer *)0, (real *)0, (real *)0, (char *)0, (integer *)0, (
 	    integer *)0, (integer *)0, (real *)0, (integer *)0, (integer *)0, 
-	    (integer *)0, (ftnint)0, (ftnint)0);
+	    (integer *)0, (ftnint)0, (ftnint)0, (ftnint)0);
     }
 
 /* Subroutine */ int swclch_(void)
@@ -1185,9 +1186,9 @@ L_swtxt:
 	    (real *)0, (integer *)0, (integer *)0, (integer *)0, (logical *)0,
 	     (logical *)0, (logical *)0, (logical *)0, (logical *)0, (real *)
 	    0, (real *)0, (real *)0, (real *)0, (real *)0, (integer *)0, (
-	    real *)0, (integer *)0, (real *)0, (real *)0, (real *)0, (integer 
+	    real *)0, (integer *)0, (real *)0, (real *)0, (char *)0, (integer 
 	    *)0, (integer *)0, (integer *)0, (real *)0, (integer *)0, (
-	    integer *)0, (integer *)0, (ftnint)0, (ftnint)0);
+	    integer *)0, (integer *)0, (ftnint)0, (ftnint)0, (ftnint)0);
     }
 
 /* Subroutine */ int swqtxw_(real *chars, integer *nchz, real *wxch, real *
@@ -1201,12 +1202,12 @@ L_swtxt:
 	    (real *)0, (integer *)0, (integer *)0, (integer *)0, (logical *)0,
 	     (logical *)0, (logical *)0, (logical *)0, (logical *)0, (real *)
 	    0, (real *)0, (real *)0, (real *)0, (real *)0, (integer *)0, 
-	    chars, nchz, wxch, wych, (real *)0, (integer *)0, (integer *)0, (
+	    chars, nchz, wxch, wych, (char *)0, (integer *)0, (integer *)0, (
 	    integer *)0, (real *)0, (integer *)0, (integer *)0, (integer *)0, 
-	    (ftnint)0, (ftnint)0);
+	    (ftnint)0, (ftnint)0, (ftnint)0);
     }
 
-/* Subroutine */ int swftfc_(real *fontname)
+/* Subroutine */ int swftfc_(char *fontname, ftnlen fontname_len)
 {
     return swdopn_0_(35, (char *)0, (char *)0, (logical *)0, (integer *)0, (
 	    integer *)0, (integer *)0, (integer *)0, (integer *)0, (real *)0, 
@@ -1218,7 +1219,7 @@ L_swtxt:
 	    0, (real *)0, (real *)0, (real *)0, (real *)0, (integer *)0, (
 	    real *)0, (integer *)0, (real *)0, (real *)0, fontname, (integer *
 	    )0, (integer *)0, (integer *)0, (real *)0, (integer *)0, (integer 
-	    *)0, (integer *)0, (ftnint)0, (ftnint)0);
+	    *)0, (integer *)0, (ftnint)0, (ftnint)0, fontname_len);
     }
 
 /* Subroutine */ int swftnm_(integer *fntnum)
@@ -1231,12 +1232,12 @@ L_swtxt:
 	    (real *)0, (integer *)0, (integer *)0, (integer *)0, (logical *)0,
 	     (logical *)0, (logical *)0, (logical *)0, (logical *)0, (real *)
 	    0, (real *)0, (real *)0, (real *)0, (real *)0, (integer *)0, (
-	    real *)0, (integer *)0, (real *)0, (real *)0, (real *)0, fntnum, (
+	    real *)0, (integer *)0, (real *)0, (real *)0, (char *)0, fntnum, (
 	    integer *)0, (integer *)0, (real *)0, (integer *)0, (integer *)0, 
-	    (integer *)0, (ftnint)0, (ftnint)0);
+	    (integer *)0, (ftnint)0, (ftnint)0, (ftnint)0);
     }
 
-/* Subroutine */ int swslft_(real *fontname)
+/* Subroutine */ int swslft_(char *fontname, ftnlen fontname_len)
 {
     return swdopn_0_(37, (char *)0, (char *)0, (logical *)0, (integer *)0, (
 	    integer *)0, (integer *)0, (integer *)0, (integer *)0, (real *)0, 
@@ -1248,10 +1249,11 @@ L_swtxt:
 	    0, (real *)0, (real *)0, (real *)0, (real *)0, (integer *)0, (
 	    real *)0, (integer *)0, (real *)0, (real *)0, fontname, (integer *
 	    )0, (integer *)0, (integer *)0, (real *)0, (integer *)0, (integer 
-	    *)0, (integer *)0, (ftnint)0, (ftnint)0);
+	    *)0, (integer *)0, (ftnint)0, (ftnint)0, fontname_len);
     }
 
-/* Subroutine */ int swgtft_(integer *inum, real *fontname, integer *ifmax)
+/* Subroutine */ int swgtft_(integer *inum, char *fontname, integer *ifmax, 
+	ftnlen fontname_len)
 {
     return swdopn_0_(38, (char *)0, (char *)0, (logical *)0, (integer *)0, (
 	    integer *)0, (integer *)0, (integer *)0, (integer *)0, (real *)0, 
@@ -1263,7 +1265,7 @@ L_swtxt:
 	    0, (real *)0, (real *)0, (real *)0, (real *)0, (integer *)0, (
 	    real *)0, (integer *)0, (real *)0, (real *)0, fontname, (integer *
 	    )0, inum, ifmax, (real *)0, (integer *)0, (integer *)0, (integer *
-	    )0, (ftnint)0, (ftnint)0);
+	    )0, (ftnint)0, (ftnint)0, fontname_len);
     }
 
 /* Subroutine */ int swlsft_(void)
@@ -1276,9 +1278,9 @@ L_swtxt:
 	    (real *)0, (integer *)0, (integer *)0, (integer *)0, (logical *)0,
 	     (logical *)0, (logical *)0, (logical *)0, (logical *)0, (real *)
 	    0, (real *)0, (real *)0, (real *)0, (real *)0, (integer *)0, (
-	    real *)0, (integer *)0, (real *)0, (real *)0, (real *)0, (integer 
+	    real *)0, (integer *)0, (real *)0, (real *)0, (char *)0, (integer 
 	    *)0, (integer *)0, (integer *)0, (real *)0, (integer *)0, (
-	    integer *)0, (integer *)0, (ftnint)0, (ftnint)0);
+	    integer *)0, (integer *)0, (ftnint)0, (ftnint)0, (ftnint)0);
     }
 
 /* Subroutine */ int swtxt_(real *wx, real *wy, real *qsizexrate, real *chars,
@@ -1292,8 +1294,8 @@ L_swtxt:
 	    integer *)0, (integer *)0, (integer *)0, (logical *)0, (logical *)
 	    0, (logical *)0, (logical *)0, (logical *)0, (real *)0, (real *)0,
 	     (real *)0, (real *)0, (real *)0, (integer *)0, chars, (integer *)
-	    0, (real *)0, (real *)0, (real *)0, (integer *)0, (integer *)0, (
-	    integer *)0, qsizexrate, ncz, irota, icentz, (ftnint)0, (ftnint)0)
-	    ;
+	    0, (real *)0, (real *)0, (char *)0, (integer *)0, (integer *)0, (
+	    integer *)0, qsizexrate, ncz, irota, icentz, (ftnint)0, (ftnint)0,
+	     (ftnint)0);
     }
 
