@@ -26,12 +26,12 @@ static integer c__3 = 3;
 {
     /* Initialized data */
 
-    static char cparas[8*20] = "MAXWNU  " "IWS     " "IPOSX   " "IPOSY   " 
+    static char cparas[8*21] = "MAXWNU  " "IWS     " "IPOSX   " "IPOSY   " 
 	    "IWIDTH  " "IHEIGHT " "LWAIT   " "LWAIT0  " "LWAIT1  " "LKEY    " 
 	    "LDUMP   " "LALT    " "LCOLOR  " "LSEP    " "LPRINT  " "LWND    " 
-	    "MODE    " "NLNSIZE " "ICLRMAP " "LFGBG   ";
-    static integer itype[20] = { 1,0,1,1,1,1,2,2,2,2,2,2,2,2,2,2,1,1,1,2 };
-    static char cparal[40*20] = "****MAXWNU                              " 
+	    "MODE    " "NLNSIZE " "ICLRMAP " "LFGBG   " "SYSFONT ";
+    static integer itype[21] = { 1,0,1,1,1,1,2,2,2,2,2,2,2,2,2,2,1,1,1,2,2 };
+    static char cparal[40*21] = "****MAXWNU                              " 
 	    "****IWS                                 " "WINDOW_X_POS        "
 	    "                    " "WINDOW_Y_POS                            " 
 	    "WINDOW_WIDTH                            " "WINDOW_HEIGHT       "
@@ -44,7 +44,8 @@ static integer c__3 = 3;
 	    "                    " "SHOW_WINDOW                             " 
 	    "****MODE                                " "****NLNSIZE         "
 	    "                    " "COLORMAP_NUMBER                         " 
-	    "****LFGBG                               ";
+	    "****LFGBG                               " "USE_SYSTEM_FONT     "
+	    "                    ";
 
     /* System generated locals */
     address a__1[3];
@@ -78,12 +79,12 @@ static integer c__3 = 3;
 	}
 
 /*     / LONG NAME / */
-    *ncp = 20;
+    *ncp = 21;
     return 0;
 /* ----------------------------------------------------------------------- */
 
 L_swpqid:
-    for (n = 1; n <= 20; ++n) {
+    for (n = 1; n <= 21; ++n) {
 	if (lchreq_(cp, cparas + (n - 1 << 3), cp_len, (ftnlen)8) || lchreq_(
 		cp, cparal + (n - 1) * 40, cp_len, (ftnlen)40)) {
 	    *idx = n;
@@ -101,7 +102,7 @@ L_swpqid:
 /* ----------------------------------------------------------------------- */
 
 L_swpqcp:
-    if (1 <= *idx && *idx <= 20) {
+    if (1 <= *idx && *idx <= 21) {
 	s_copy(cp, cparas + (*idx - 1 << 3), cp_len, (ftnlen)8);
     } else {
 	msgdmp_("E", "SWPQCP", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
@@ -111,7 +112,7 @@ L_swpqcp:
 /* ----------------------------------------------------------------------- */
 
 L_swpqcl:
-    if (1 <= *idx && *idx <= 20) {
+    if (1 <= *idx && *idx <= 21) {
 	s_copy(cp, cparal + (*idx - 1) * 40, cp_len, (ftnlen)40);
     } else {
 	msgdmp_("E", "SWPQCL", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
@@ -121,7 +122,7 @@ L_swpqcl:
 /* ----------------------------------------------------------------------- */
 
 L_swpqit:
-    if (1 <= *idx && *idx <= 20) {
+    if (1 <= *idx && *idx <= 21) {
 	*itp = itype[*idx - 1];
     } else {
 	msgdmp_("E", "SWPQIT", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
@@ -131,7 +132,7 @@ L_swpqit:
 /* ----------------------------------------------------------------------- */
 
 L_swpqvl:
-    if (1 <= *idx && *idx <= 20) {
+    if (1 <= *idx && *idx <= 21) {
 	if (itype[*idx - 1] == 1) {
 	    swiqid_(cparas + (*idx - 1 << 3), &id, (ftnlen)8);
 	    swiqvl_(&id, ipara);
@@ -150,7 +151,7 @@ L_swpqvl:
 /* ----------------------------------------------------------------------- */
 
 L_swpsvl:
-    if (1 <= *idx && *idx <= 20) {
+    if (1 <= *idx && *idx <= 21) {
 	if (itype[*idx - 1] == 1) {
 	    swiqid_(cparas + (*idx - 1 << 3), &id, (ftnlen)8);
 	    swisvl_(&id, ipara);
@@ -169,7 +170,7 @@ L_swpsvl:
 /* ----------------------------------------------------------------------- */
 
 L_swpqin:
-    for (n = 1; n <= 20; ++n) {
+    for (n = 1; n <= 21; ++n) {
 	if (lchreq_(cp, cparas + (n - 1 << 3), cp_len, (ftnlen)8) || lchreq_(
 		cp, cparal + (n - 1) * 40, cp_len, (ftnlen)40)) {
 	    *in = n;
