@@ -1,9 +1,16 @@
-/* szm3op.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Common Block Declarations */
 
@@ -29,7 +36,7 @@ static integer c__0 = 0;
 /* ----------------------------------------------------------------------- */
 /*     POLYMARKER PRIMITIVE (3-D) */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int szm3op_0_(int n__, integer *itype, integer *index, real *
 	rsize)
@@ -43,6 +50,7 @@ static integer c__0 = 0;
 	    ;
 
     /* Local variables */
+    static real pmf;
     static char cobj[80];
     extern /* Character */ VOID csgi_(char *, ftnlen, integer *);
     extern /* Subroutine */ int cdblk_(char *, ftnlen), gllget_(char *, 
@@ -50,7 +58,6 @@ static integer c__0 = 0;
 	    char *, real *, ftnlen), sgrget_(char *, real *, ftnlen), swocls_(
 	    char *, ftnlen), swoopn_(char *, char *, ftnlen, ftnlen), sztxcl_(
 	    void), sztxop_(real *, integer *, integer *, integer *);
-    static real pmf;
 
     /* Fortran I/O blocks */
     static icilist io___3 = { 0, cobj, 0, "(2I8,F8.5)", 80, 1 };
