@@ -29,11 +29,16 @@ static integer c__1 = 1;
     static integer ncntz = 0;
 
     /* System generated locals */
-    integer i__1;
+    integer i__1, i__2;
     real r__1, r__2;
     char ch__1[1];
 
+    /* Builtin functions */
+    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
+
     /* Local variables */
+    static char fontname[70];
+    static logical markfont;
     static integer n;
     static real dz;
     static integer id1, id2, id3;
@@ -43,12 +48,17 @@ static integer c__1 = 1;
     extern /* Character */ VOID csgi_(char *, ftnlen, integer *);
     extern integer isgc_(char *, ftnlen);
     static char csub[1];
-    static integer nctl, ncnt, nchz, isub, msub, nsub;
+    static integer nctl, isub, ncnt, nchz, msub, nsub;
+    extern integer lenz_(char *, ftnlen);
     static char csup[1], crst[1];
     static integer isup, irst, msup, nsup, mrst, nchar;
-    static real rfact, small;
+    static real rfact;
+    static integer index;
+    static real small;
     static logical lcntl;
     static real shift;
+    static integer ifont;
+    extern /* Subroutine */ int swsfw_(integer *);
     extern integer indxcf_(char *, integer *, integer *, char *, ftnlen, 
 	    ftnlen);
     extern /* Subroutine */ int sgiget_(char *, integer *, ftnlen);
@@ -56,11 +66,18 @@ static integer c__1 = 1;
 	    ftnlen);
     extern /* Subroutine */ int sglget_(char *, logical *, ftnlen), msgdmp_(
 	    char *, char *, char *, ftnlen, ftnlen, ftnlen), sgrget_(char *, 
-	    real *, ftnlen);
-    static integer idxsub, ndxsub, idxsup;
+	    real *, ftnlen), swcget_(char *, char *, ftnlen, ftnlen), swftfc_(
+	    char *, ftnlen);
+    static integer idxsub;
+    static logical lfprop;
+    static integer ndxsub;
+    extern /* Subroutine */ int swlget_(char *, logical *, ftnlen);
+    static integer idxsup;
     extern /* Subroutine */ int szfint_(integer *);
     static integer idxrst, ndxsup;
-    extern /* Subroutine */ int szqfnw_(real *, real *);
+    extern /* Subroutine */ int szqidx_(integer *), szqfnw_(real *, real *), 
+	    swqtxw_(char *, integer *, real *, real *, ftnlen);
+    static logical sysfont;
 
 /*     / GET FONT INFORMATION / */
     szfint_(&ncnt);
@@ -69,6 +86,46 @@ static integer c__1 = 1;
 	ncntz = ncnt;
     }
     nchz = lenc_(chars, chars_len);
+/*     / FOR SYSTEM FONTS / */
+/*     / PROCCESS IF NOT MARKER / */
+    swlget_("SYSFONT", &sysfont, (ftnlen)7);
+    if (sysfont) {
+	szqidx_(&index);
+	swcget_("FONTNAME", fontname, (ftnlen)8, (ftnlen)70);
+/*     / WHEN FONTNAME IS NOT GIVEN / */
+	if (lenz_(fontname, (ftnlen)70) == 0) {
+	    sglget_("LFPROP", &lfprop, (ftnlen)6);
+	    if (lfprop) {
+		sgiget_("IFONT", &ifont, (ftnlen)5);
+		if (ifont == 1) {
+		    s_copy(fontname, "Sans", (ftnlen)70, (ftnlen)4);
+		} else if (ifont == 2) {
+		    s_copy(fontname, "Serif", (ftnlen)70, (ftnlen)5);
+		}
+	    } else {
+		s_copy(fontname, "Monospace", (ftnlen)70, (ftnlen)9);
+	    }
+	    swftfc_(fontname, (ftnlen)70);
+/* Computing MAX */
+	    i__2 = index % 10;
+	    i__1 = max(i__2,1);
+	    swsfw_(&i__1);
+	} else {
+	    swftfc_(fontname, (ftnlen)70);
+	}
+	idx = isgc_(chars, (ftnlen)1);
+	sglget_("MARKFONT", &markfont, (ftnlen)8);
+	if (idx > 18 || markfont) {
+	    if (idx < 18) {
+/* Computing MAX */
+		i__2 = index % 10;
+		i__1 = max(i__2,1);
+		swsfw_(&i__1);
+	    }
+	    swqtxw_(chars, &nchz, wxch, wych, chars_len);
+	    goto L40;
+	}
+    }
 /*     / CHECK LCNTL OPTION / */
     sglget_("LCNTL", &lcntl, (ftnlen)5);
     if (lcntl) {
@@ -178,6 +235,7 @@ L20:
 	}
 	*wych = 1.f;
     }
+L40:
     return 0;
 } /* szqtxw_ */
 
