@@ -1,9 +1,16 @@
-/* udiget.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
@@ -12,7 +19,7 @@ static integer c__1 = 1;
 /* ----------------------------------------------------------------------- */
 /*     UDIGET / UDISET / UDISTX */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int udiget_0_(int n__, char *cp, integer *ipara, ftnlen 
 	cp_len)
@@ -20,12 +27,12 @@ static integer c__1 = 1;
     static char cl[40];
     static integer ip;
     static char cx[8];
+    static integer idx;
     extern /* Subroutine */ int udiqid_(char *, integer *, ftnlen), udiqcl_(
 	    integer *, char *, ftnlen), udiqcp_(integer *, char *, ftnlen), 
 	    rliget_(char *, integer *, integer *, ftnlen), rtiget_(char *, 
 	    char *, integer *, integer *, ftnlen, ftnlen), udiqvl_(integer *, 
 	    integer *), udisvl_(integer *, integer *);
-    static integer idx;
 
     switch(n__) {
 	case 1: goto L_udiset;
