@@ -1,9 +1,16 @@
-/* ugiqnp.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
@@ -13,7 +20,7 @@ static integer c__10 = 10;
 /* ----------------------------------------------------------------------- */
 /*     UGIQNP / UGIQID / UGIQCP / UGIQVL / UGISVL */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int ugiqnp_0_(int n__, integer *ncp, char *cp, integer *idx, 
 	integer *ipara, integer *in, ftnlen cp_len)
@@ -41,9 +48,9 @@ static integer c__10 = 10;
 	     s_copy(char *, char *, ftnlen, ftnlen);
 
     /* Local variables */
+    static integer n;
     extern integer lenc_(char *, ftnlen);
     static char cmsg[80];
-    static integer n;
     extern logical lchreq_(char *, char *, ftnlen, ftnlen);
     extern /* Subroutine */ int rliget_(char *, integer *, integer *, ftnlen),
 	     msgdmp_(char *, char *, char *, ftnlen, ftnlen, ftnlen), rtiget_(
