@@ -1,9 +1,16 @@
-/* ugunit.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
@@ -12,11 +19,11 @@ static integer c__1 = 1;
 /* ----------------------------------------------------------------------- */
 /*     UGUNIT */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int ugunit_(void)
 {
-    static real uvx1, uvx2, uvy1, uvy2;
+    static real vx1, vx2, vy1, vy2, uvx1, uvx2, uvy1, uvy2;
     static integer index;
     static real vxoff, vyoff, xfact2, yfact2, rundef;
     extern /* Subroutine */ int ugiget_(char *, integer *, ftnlen), szlacl_(
@@ -25,7 +32,7 @@ static integer c__1 = 1;
     static real vxuloc, vyuloc;
     extern /* Subroutine */ int sgqvpt_(real *, real *, real *, real *), 
 	    szlazv_(real *, real *, real *, real *);
-    static real uxunit, vxunit, uyunit, vx1, vx2, vy1, vy2, vyunit;
+    static real uxunit, vxunit, uyunit, vyunit;
 
 /*     / GET INTERNAL PARAMETERES / */
     ugrget_("RUNDEF", &rundef, (ftnlen)6);
