@@ -239,7 +239,7 @@ L100:
 		    if (lcntl) {
 /*              IF(LSFNT) THEN */
 /* Writing concatenation */
-			i__4[0] = 4, a__1[0] = "10^{";
+			i__4[0] = 5, a__1[0] = "10\\^{";
 			i__4[1] = lenz_(chr, (ftnlen)8), a__1[1] = chr;
 			i__4[2] = 1, a__1[2] = "}";
 			s_cat(ch + ((nbl - 1 << 4) + 2), a__1, i__4, &c__3, (
