@@ -146,7 +146,7 @@ L20:
 /* Writing concatenation */
 	    csgi_(ch__1, (ftnlen)1, &c__194);
 	    i__1[0] = 1, a__1[0] = ch__1;
-	    i__1[1] = 4, a__1[1] = "10^{";
+	    i__1[1] = 5, a__1[1] = "10\\^{";
 	    i__1[2] = lenc_(cexp2, (ftnlen)16), a__1[2] = cexp2;
 	    i__1[3] = 1, a__1[3] = "}";
 	    s_cat(cexp, a__1, i__1, &c__4, (ftnlen)16);
