@@ -1,9 +1,16 @@
-/* uxpttl.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
@@ -13,7 +20,7 @@ static integer c__2 = 2;
 /* ----------------------------------------------------------------------- */
 /*     UXPTTL : PLOT TITLE */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int uxpttl_(char *cside, integer *islct, char *cttl, real *
 	px, ftnlen cside_len, ftnlen cttl_len)
@@ -30,6 +37,9 @@ static integer c__2 = 2;
     integer i_sign(integer *, integer *);
 
     /* Local variables */
+    static integer ic, nc;
+    static real ux[2], pad, rlc;
+    static integer lcw;
     extern integer lenc_(char *, ftnlen);
     static integer nctl;
     static real wxch, wych, uxmn, uymn, posy, uxmx, uymx;
@@ -39,8 +49,6 @@ static integer c__2 = 2;
     static char cslct[1];
     static integer irota, jrota;
     static real roffx, roffz, rsize;
-    static integer ic, nc;
-    static real ux[2];
     extern logical lchreq_(char *, char *, ftnlen, ftnlen);
     static logical lbound;
     extern /* Subroutine */ int msgdmp_(char *, char *, char *, ftnlen, 
@@ -52,8 +60,6 @@ static integer c__2 = 2;
 	    uziget_(char *, integer *, ftnlen), uzlget_(char *, logical *, 
 	    ftnlen), uzrget_(char *, real *, ftnlen), uzrset_(char *, real *, 
 	    ftnlen), szqtxw_(char *, integer *, real *, real *, ftnlen);
-    static real pad, rlc;
-    static integer lcw;
 
     /* Fortran I/O blocks */
     static icilist io___3 = { 0, cslct, 0, "(I1)", 1, 1 };
