@@ -1,14 +1,22 @@
-/* Copyright (C) by GFD-Dennou Club, 1999-2000.  All rights reserved. */
-/* cladj.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* ----------------------------------------------------------------------- */
 /*     CLADJ */
 /* ----------------------------------------------------------------------- */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/* ----------------------------------------------------------------------- */
 /* Subroutine */ int cladj_(char *chr, ftnlen chr_len)
 {
     /* System generated locals */
@@ -19,8 +27,8 @@
     /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
 
     /* Local variables */
-    extern integer lenb_(char *, ftnlen);
     static integer i__, lc1, lc2;
+    extern integer lenb_(char *, ftnlen);
 
     lc1 = i_len(chr, chr_len);
     lc2 = lenb_(chr, chr_len);
